@@ -12,7 +12,7 @@ class SamResource:
     with any CloudFormation constructs, like DependsOn, Conditions etc.
     """
 
-    type = None  # noqa: A003
+    type = None
     properties: Dict[str, Any] = {}  # TODO: Replace `Any` with something more specific
 
     def __init__(self, resource_dict: Dict[str, Any]) -> None:
